@@ -87,8 +87,6 @@
 
 #define GST_EVENT_SEQNUM(e) ((GstEvent*)e)->abidata.seqnum
 
-static void gst_event_init (GTypeInstance * instance, gpointer g_class);
-static void gst_event_class_init (gpointer g_class, gpointer class_data);
 static void gst_event_finalize (GstEvent * event);
 static GstEvent *_gst_event_copy (GstEvent * event);
 
@@ -117,10 +115,12 @@ static GstEventQuarks event_quarks[] = {
   {GST_EVENT_NEWSEGMENT, "newsegment", 0},
   {GST_EVENT_TAG, "tag", 0},
   {GST_EVENT_BUFFERSIZE, "buffersize", 0},
+  {GST_EVENT_SINK_MESSAGE, "sink-message", 0},
   {GST_EVENT_QOS, "qos", 0},
   {GST_EVENT_SEEK, "seek", 0},
   {GST_EVENT_NAVIGATION, "navigation", 0},
   {GST_EVENT_LATENCY, "latency", 0},
+  {GST_EVENT_STEP, "step", 0},
   {GST_EVENT_CUSTOM_UPSTREAM, "custom-upstream", 0},
   {GST_EVENT_CUSTOM_DOWNSTREAM, "custom-downstream", 0},
   {GST_EVENT_CUSTOM_DOWNSTREAM_OOB, "custom-downstream-oob", 0},
@@ -188,57 +188,30 @@ gst_event_type_get_flags (GstEventType type)
   return ret;
 }
 
-GType
-gst_event_get_type (void)
-{
-  static GType _gst_event_type = 0;
-  int i;
-
-  if (G_UNLIKELY (_gst_event_type == 0)) {
-    static const GTypeInfo event_info = {
-      sizeof (GstEventClass),
-      NULL,
-      NULL,
-      gst_event_class_init,
-      NULL,
-      NULL,
-      sizeof (GstEvent),
-      0,
-      gst_event_init,
-      NULL
-    };
-
-    _gst_event_type = g_type_register_static (GST_TYPE_MINI_OBJECT,
-        "GstEvent", &event_info, 0);
-
-    for (i = 0; event_quarks[i].name; i++) {
-      event_quarks[i].quark = g_quark_from_static_string (event_quarks[i].name);
-    }
-  }
-
-  return _gst_event_type;
+#define _do_init \
+{ \
+  gint i; \
+  \
+  for (i = 0; event_quarks[i].name; i++) { \
+    event_quarks[i].quark = g_quark_from_static_string (event_quarks[i].name); \
+  } \
 }
 
+G_DEFINE_TYPE_WITH_CODE (GstEvent, gst_event, GST_TYPE_MINI_OBJECT, _do_init);
+
 static void
-gst_event_class_init (gpointer g_class, gpointer class_data)
+gst_event_class_init (GstEventClass * klass)
 {
-  GstEventClass *event_class = GST_EVENT_CLASS (g_class);
+  parent_class = g_type_class_peek_parent (klass);
 
-  parent_class = g_type_class_peek_parent (g_class);
-
-  event_class->mini_object_class.copy =
-      (GstMiniObjectCopyFunction) _gst_event_copy;
-  event_class->mini_object_class.finalize =
+  klass->mini_object_class.copy = (GstMiniObjectCopyFunction) _gst_event_copy;
+  klass->mini_object_class.finalize =
       (GstMiniObjectFinalizeFunction) gst_event_finalize;
 }
 
 static void
-gst_event_init (GTypeInstance * instance, gpointer g_class)
+gst_event_init (GstEvent * event)
 {
-  GstEvent *event;
-
-  event = GST_EVENT (instance);
-
   GST_EVENT_TIMESTAMP (event) = GST_CLOCK_TIME_NONE;
 }
 
@@ -260,7 +233,7 @@ gst_event_finalize (GstEvent * event)
     gst_structure_free (event->structure);
   }
 
-  GST_MINI_OBJECT_CLASS (parent_class)->finalize (GST_MINI_OBJECT (event));
+/*   GST_MINI_OBJECT_CLASS (parent_class)->finalize (GST_MINI_OBJECT (event)); */
 }
 
 static GstEvent *
@@ -436,6 +409,10 @@ gst_event_set_seqnum (GstEvent * event, guint32 seqnum)
   GST_EVENT_SEQNUM (event) = seqnum;
 }
 
+/* FIXME 0.11: It would be nice to have flush events
+ * that don't reset the running time in the sinks
+ */
+
 /**
  * gst_event_new_flush_start:
  *
@@ -466,7 +443,7 @@ gst_event_new_flush_start (void)
  * gst_event_new_flush_stop:
  *
  * Allocate a new flush stop event. The flush stop event can be sent
- * upstream and downstream and travels out-of-bounds with the dataflow.
+ * upstream and downstream and travels serialized with the dataflow.
  * It is typically sent after sending a FLUSH_START event to make the
  * pads accept data again.
  *
@@ -571,7 +548,8 @@ gst_event_parse_new_segment (GstEvent * event, gboolean * update,
  * The newsegment event marks the range of buffers to be processed. All
  * data not within the segment range is not to be processed. This can be
  * used intelligently by plugins to apply more efficient methods of skipping
- * unneeded data.
+ * unneeded data. The valid range is expressed with the @start and @stop
+ * values.
  *
  * The position value of the segment is used in conjunction with the start
  * value to convert the buffer timestamps into the stream time. This is 
@@ -630,8 +608,7 @@ gst_event_new_new_segment_full (gboolean update, gdouble rate,
   if (stop != -1)
     g_return_val_if_fail (start <= stop, NULL);
 
-  structure = gst_structure_empty_new ("GstEventNewsegment");
-  gst_structure_id_set (structure,
+  structure = gst_structure_id_new (GST_QUARK (EVENT_NEWSEGMENT),
       GST_QUARK (UPDATE), G_TYPE_BOOLEAN, update,
       GST_QUARK (RATE), G_TYPE_DOUBLE, rate,
       GST_QUARK (APPLIED_RATE), G_TYPE_DOUBLE, applied_rate,
@@ -762,8 +739,7 @@ gst_event_new_buffer_size (GstFormat format, gint64 minsize,
       ", maxsize %" G_GINT64_FORMAT ", async %d", gst_format_get_name (format),
       minsize, maxsize, async);
 
-  structure = gst_structure_empty_new ("GstEventBufferSize");
-  gst_structure_id_set (structure,
+  structure = gst_structure_id_new (GST_QUARK (EVENT_BUFFER_SIZE),
       GST_QUARK (FORMAT), GST_TYPE_FORMAT, format,
       GST_QUARK (MINSIZE), G_TYPE_INT64, minsize,
       GST_QUARK (MAXSIZE), G_TYPE_INT64, maxsize,
@@ -868,8 +844,7 @@ gst_event_new_qos (gdouble proportion, GstClockTimeDiff diff,
       ", timestamp %" GST_TIME_FORMAT, proportion,
       diff, GST_TIME_ARGS (timestamp));
 
-  structure = gst_structure_empty_new ("GstEventQOS");
-  gst_structure_id_set (structure,
+  structure = gst_structure_id_new (GST_QUARK (EVENT_QOS),
       GST_QUARK (PROPORTION), G_TYPE_DOUBLE, proportion,
       GST_QUARK (DIFF), G_TYPE_INT64, diff,
       GST_QUARK (TIMESTAMP), G_TYPE_UINT64, timestamp, NULL);
@@ -981,8 +956,7 @@ gst_event_new_seek (gdouble rate, GstFormat format, GstSeekFlags flags,
         stop);
   }
 
-  structure = gst_structure_empty_new ("GstEventSeek");
-  gst_structure_id_set (structure,
+  structure = gst_structure_id_new (GST_QUARK (EVENT_SEEK),
       GST_QUARK (RATE), G_TYPE_DOUBLE, rate,
       GST_QUARK (FORMAT), GST_TYPE_FORMAT, format,
       GST_QUARK (FLAGS), GST_TYPE_SEEK_FLAGS, flags,
@@ -1072,7 +1046,7 @@ gst_event_new_navigation (GstStructure * structure)
  *
  * Create a new latency event. The event is sent upstream from the sinks and
  * notifies elements that they should add an additional @latency to the
- * timestamps before synchronising against the clock.
+ * running time before synchronising against the clock.
  *
  * The latency is mostly used in live sinks and is always expressed in
  * the time format.
@@ -1090,8 +1064,7 @@ gst_event_new_latency (GstClockTime latency)
   GST_CAT_INFO (GST_CAT_EVENT,
       "creating latency event %" GST_TIME_FORMAT, GST_TIME_ARGS (latency));
 
-  structure = gst_structure_empty_new ("GstEventLatency");
-  gst_structure_id_set (structure,
+  structure = gst_structure_id_new (GST_QUARK (EVENT_LATENCY),
       GST_QUARK (LATENCY), G_TYPE_UINT64, latency, NULL);
   event = gst_event_new_custom (GST_EVENT_LATENCY, structure);
 
@@ -1121,3 +1094,143 @@ gst_event_parse_latency (GstEvent * event, GstClockTime * latency)
         g_value_get_uint64 (gst_structure_id_get_value (structure,
             GST_QUARK (LATENCY)));
 }
+
+/**
+ * gst_event_new_step:
+ * @format: the format of @amount
+ * @amount: the amount of data to step
+ * @rate: the step rate
+ * @flush: flushing steps
+ * @intermediate: intermediate steps
+ *
+ * Create a new step event. The purpose of the step event is to instruct a sink
+ * to skip @amount (expressed in @format) of media. It can be used to implement
+ * stepping through the video frame by frame or for doing fast trick modes.
+ *
+ * A rate of <= 0.0 is not allowed, pause the pipeline or reverse the playback
+ * direction of the pipeline to get the same effect.
+ *
+ * The @flush flag will clear any pending data in the pipeline before starting
+ * the step operation.
+ *
+ * The @intermediate flag instructs the pipeline that this step operation is
+ * part of a larger step operation.
+ *
+ * Returns: a new #GstEvent
+ *
+ * Since: 0.10.24
+ */
+GstEvent *
+gst_event_new_step (GstFormat format, guint64 amount, gdouble rate,
+    gboolean flush, gboolean intermediate)
+{
+  GstEvent *event;
+  GstStructure *structure;
+
+  g_return_val_if_fail (rate > 0.0, NULL);
+
+  GST_CAT_INFO (GST_CAT_EVENT, "creating step event");
+
+  structure = gst_structure_id_new (GST_QUARK (EVENT_STEP),
+      GST_QUARK (FORMAT), GST_TYPE_FORMAT, format,
+      GST_QUARK (AMOUNT), G_TYPE_UINT64, amount,
+      GST_QUARK (RATE), G_TYPE_DOUBLE, rate,
+      GST_QUARK (FLUSH), G_TYPE_BOOLEAN, flush,
+      GST_QUARK (INTERMEDIATE), G_TYPE_BOOLEAN, intermediate, NULL);
+  event = gst_event_new_custom (GST_EVENT_STEP, structure);
+
+  return event;
+}
+
+/**
+ * gst_event_parse_step:
+ * @event: The event to query
+ * @format: A pointer to store the format in.
+ * @amount: A pointer to store the amount in.
+ * @rate: A pointer to store the rate in.
+ * @flush: A pointer to store the flush boolean in.
+ * @intermediate: A pointer to store the intermediate boolean in.
+ *
+ * Parse the step event.
+ *
+ * Since: 0.10.24
+ */
+void
+gst_event_parse_step (GstEvent * event, GstFormat * format, guint64 * amount,
+    gdouble * rate, gboolean * flush, gboolean * intermediate)
+{
+  const GstStructure *structure;
+
+  g_return_if_fail (GST_IS_EVENT (event));
+  g_return_if_fail (GST_EVENT_TYPE (event) == GST_EVENT_STEP);
+
+  structure = gst_event_get_structure (event);
+  if (format)
+    *format = g_value_get_enum (gst_structure_id_get_value (structure,
+            GST_QUARK (FORMAT)));
+  if (amount)
+    *amount = g_value_get_uint64 (gst_structure_id_get_value (structure,
+            GST_QUARK (AMOUNT)));
+  if (rate)
+    *rate = g_value_get_double (gst_structure_id_get_value (structure,
+            GST_QUARK (RATE)));
+  if (flush)
+    *flush = g_value_get_boolean (gst_structure_id_get_value (structure,
+            GST_QUARK (FLUSH)));
+  if (intermediate)
+    *intermediate = g_value_get_boolean (gst_structure_id_get_value (structure,
+            GST_QUARK (INTERMEDIATE)));
+}
+
+/**
+ * gst_event_new_sink_message:
+ * @msg: The #GstMessage to be posted
+ *
+ * Create a new sink-message event. The purpose of the sink-message event is
+ * to instruct a sink to post the message contained in the event synchronized
+ * with the stream.
+ *
+ * Returns: a new #GstEvent
+ *
+ * Since: 0.10.26
+ */
+GstEvent *
+gst_event_new_sink_message (GstMessage * msg)
+{
+  GstEvent *event;
+  GstStructure *structure;
+
+  g_return_val_if_fail (msg != NULL, NULL);
+
+  GST_CAT_INFO (GST_CAT_EVENT, "creating sink-message event");
+
+  structure = gst_structure_id_new (GST_QUARK (EVENT_SINK_MESSAGE),
+      GST_QUARK (MESSAGE), GST_TYPE_MESSAGE, msg, NULL);
+  event = gst_event_new_custom (GST_EVENT_SINK_MESSAGE, structure);
+
+  return event;
+}
+
+/**
+ * gst_event_parse_sink_message:
+ * @event: The event to query
+ * @msg: A pointer to store the #GstMessage in.
+ *
+ * Parse the sink-message event. Unref @msg after usage.
+ *
+ * Since: 0.10.26
+ */
+void
+gst_event_parse_sink_message (GstEvent * event, GstMessage ** msg)
+{
+  const GstStructure *structure;
+
+  g_return_if_fail (GST_IS_EVENT (event));
+  g_return_if_fail (GST_EVENT_TYPE (event) == GST_EVENT_SINK_MESSAGE);
+
+  structure = gst_event_get_structure (event);
+  if (msg)
+    *msg =
+        GST_MESSAGE (gst_value_dup_mini_object (gst_structure_id_get_value
+            (structure, GST_QUARK (MESSAGE))));
+}
