@@ -99,10 +99,14 @@ GST_START_TEST (test_deserialize_gint64)
   const char *strings[] = {
     "12345678901",
     "-12345678901",
+    "1152921504606846976",
+    "-1152921504606846976",
   };
   gint64 results[] = {
     12345678901LL,
     -12345678901LL,
+    1152921504606846976LL,
+    -1152921504606846976LL,
   };
   int i;
 
@@ -120,6 +124,41 @@ GST_START_TEST (test_deserialize_gint64)
 
 GST_END_TEST;
 
+GST_START_TEST (test_deserialize_guint64)
+{
+  GValue value = { 0 };
+  const char *strings[] = {
+    "0xffffffffffffffff",
+    "9223372036854775810",
+    "-9223372036854775810",
+    "-1",
+    "1",
+    "-0",
+  };
+  guint64 results[] = {
+    0xffffffffffffffffULL,
+    9223372036854775810ULL,
+    9223372036854775806ULL,
+    (guint64) - 1,
+    1,
+    0,
+  };
+  int i;
+
+  g_value_init (&value, G_TYPE_UINT64);
+
+  for (i = 0; i < G_N_ELEMENTS (strings); ++i) {
+    fail_unless (gst_value_deserialize (&value, strings[i]),
+        "could not deserialize %s (%d)", strings[i], i);
+    fail_unless (g_value_get_uint64 (&value) == results[i],
+        "resulting value is %" G_GUINT64_FORMAT ", not %" G_GUINT64_FORMAT
+        ", for string %s (%d)", g_value_get_uint64 (&value),
+        results[i], strings[i], i);
+  }
+}
+
+GST_END_TEST;
+
 GST_START_TEST (test_deserialize_gstfraction)
 {
   GValue value = { 0 };
@@ -178,21 +217,21 @@ GST_START_TEST (test_deserialize_gint)
     "0xFFFFFFFFFFFFFFFF",
     "0xEFFFFFFF",
   };
+  /* some casts need to be explicit because of unsigned -> signed */
   gint results[] = {
     123456,
     -123456,
     0xFFFF,
     0xFFFF,
     0x7FFFFFFF,
-    0x80000000,
-    0x80000000,
-    0xFF000000,
+    (gint) 0x80000000,
+    (gint) 0x80000000,
+    (gint) 0xFF000000,
     -1,
-    0xFFFFFFFF,
+    (gint) 0xFFFFFFFF,
     -1,
-    /* cast needs to be explicit because of unsigned -> signed */
     (gint) 0xFFFFFFFFFFFFFFFFLL,
-    0xEFFFFFFF,
+    (gint) 0xEFFFFFFF,
   };
   int i;
 
@@ -261,7 +300,7 @@ GST_START_TEST (test_deserialize_guint)
   };
   guint results[] = {
     123456,
-    -123456,
+    (guint) - 123456,
     0xFFFF,
     0xFFFF,
     0x7FFFFFFF,
@@ -389,7 +428,8 @@ GST_START_TEST (test_string)
   gchar *try[] = {
     "Dude",
     "Hi, I'm a string",
-    "tüüüt!"
+    "tüüüt!",
+    "\"\""                      /* Empty string */
   };
   gchar *tmp;
   GValue v = { 0, };
@@ -426,7 +466,8 @@ GST_START_TEST (test_deserialize_string)
     {
     "", ""},                    /* empty strings */
     {
-    "\"\"", ""},                /* FAILURES */
+    "\"\"", ""},                /* quoted empty string -> empty string */
+        /* Expected FAILURES: */
     {
     "\"", NULL},                /* missing second quote */
     {
@@ -499,6 +540,12 @@ GST_START_TEST (test_value_compare)
   fail_unless (gst_value_compare (&value1, &value2) == GST_VALUE_LESS_THAN);
   fail_unless (gst_value_compare (&value2, &value1) == GST_VALUE_GREATER_THAN);
   fail_unless (gst_value_compare (&value1, &value1) == GST_VALUE_EQUAL);
+  /* Test some NULL string comparisons */
+  g_value_set_string (&value2, NULL);
+  fail_unless (gst_value_compare (&value1, &value2) == GST_VALUE_UNORDERED);
+  fail_unless (gst_value_compare (&value2, &value1) == GST_VALUE_UNORDERED);
+  fail_unless (gst_value_compare (&value2, &value2) == GST_VALUE_EQUAL);
+
   g_value_unset (&value1);
   g_value_unset (&value2);
 
@@ -1467,6 +1514,54 @@ GST_START_TEST (test_value_subtract_fraction_range)
 
 GST_END_TEST;
 
+/* Test set subtraction operations on fraction lists */
+GST_START_TEST (test_value_subtract_fraction_list)
+{
+  GValue list1 = { 0 };
+  GValue list2 = { 0 };
+  GValue val1 = { 0 };
+  GValue val2 = { 0 };
+  GValue tmp = { 0 };
+  gboolean ret;
+
+  g_value_init (&list1, GST_TYPE_LIST);
+  g_value_init (&val1, GST_TYPE_FRACTION);
+  gst_value_set_fraction (&val1, 15, 2);
+  gst_value_list_append_value (&list1, &val1);
+  g_value_init (&tmp, GST_TYPE_FRACTION);
+  gst_value_set_fraction (&tmp, 5, 1);
+  gst_value_list_append_value (&list1, &tmp);
+  g_value_unset (&tmp);
+
+  g_value_init (&list2, GST_TYPE_LIST);
+  g_value_init (&val2, GST_TYPE_FRACTION);
+  gst_value_set_fraction (&val2, 15, 1);
+  gst_value_list_append_value (&list2, &val2);
+  g_value_init (&tmp, GST_TYPE_FRACTION);
+  gst_value_set_fraction (&tmp, 5, 1);
+  gst_value_list_append_value (&list2, &tmp);
+  g_value_unset (&tmp);
+
+  /* should subtract all common elements */
+  ret = gst_value_subtract (&tmp, &list1, &list2);
+  fail_unless (ret == TRUE);
+  fail_unless (gst_value_compare (&tmp, &val1) == GST_VALUE_EQUAL);
+  g_value_unset (&val1);
+  g_value_unset (&tmp);
+
+  ret = gst_value_subtract (&tmp, &list2, &list1);
+  fail_unless (ret == TRUE);
+  fail_unless (gst_value_compare (&tmp, &val2) == GST_VALUE_EQUAL);
+  g_value_unset (&val2);
+  g_value_unset (&tmp);
+
+  g_value_unset (&list1);
+  g_value_unset (&list2);
+}
+
+GST_END_TEST;
+
+
 GST_START_TEST (test_date)
 {
   GstStructure *s;
@@ -1618,7 +1713,49 @@ GST_START_TEST (test_serialize_deserialize_format_enum)
 
 GST_END_TEST;
 
-Suite *
+GST_START_TEST (test_serialize_deserialize_caps)
+{
+  GValue value = { 0 }, value2 = {
+  0};
+  GstCaps *caps, *caps2;
+  gchar *serialized;
+
+  caps = gst_caps_new_simple ("test/caps",
+      "foo", G_TYPE_INT, 10, "bar", G_TYPE_STRING, "test", NULL);
+  fail_if (GST_CAPS_REFCOUNT_VALUE (caps) != 1);
+
+  /* and assign caps to gvalue */
+  g_value_init (&value, GST_TYPE_CAPS);
+  g_value_take_boxed (&value, caps);
+  fail_if (GST_CAPS_REFCOUNT_VALUE (caps) != 1);
+
+  /* now serialize it */
+  serialized = gst_value_serialize (&value);
+  GST_DEBUG ("serialized caps to %s", serialized);
+  fail_unless (serialized != NULL);
+
+  /* refcount should not change */
+  fail_if (GST_CAPS_REFCOUNT_VALUE (caps) != 1);
+
+  /* now deserialize again */
+  g_value_init (&value2, GST_TYPE_CAPS);
+  gst_value_deserialize (&value2, serialized);
+
+  caps2 = g_value_get_boxed (&value2);
+  fail_if (GST_CAPS_REFCOUNT_VALUE (caps2) != 1);
+
+  /* they should be equal */
+  fail_unless (gst_caps_is_equal (caps, caps2));
+
+  /* cleanup */
+  g_value_unset (&value);
+  g_value_unset (&value2);
+  g_free (serialized);
+}
+
+GST_END_TEST;
+
+static Suite *
 gst_value_suite (void)
 {
   Suite *s = suite_create ("GstValue");
@@ -1632,6 +1769,7 @@ gst_value_suite (void)
   tcase_add_test (tc_chain, test_deserialize_guint);
   tcase_add_test (tc_chain, test_deserialize_guint_failures);
   tcase_add_test (tc_chain, test_deserialize_gint64);
+  tcase_add_test (tc_chain, test_deserialize_guint64);
   tcase_add_test (tc_chain, test_deserialize_gstfraction);
   tcase_add_test (tc_chain, test_serialize_flags);
   tcase_add_test (tc_chain, test_deserialize_flags);
@@ -1644,8 +1782,10 @@ gst_value_suite (void)
   tcase_add_test (tc_chain, test_value_subtract_double);
   tcase_add_test (tc_chain, test_value_subtract_fraction);
   tcase_add_test (tc_chain, test_value_subtract_fraction_range);
+  tcase_add_test (tc_chain, test_value_subtract_fraction_list);
   tcase_add_test (tc_chain, test_date);
   tcase_add_test (tc_chain, test_fraction_range);
+  tcase_add_test (tc_chain, test_serialize_deserialize_caps);
 
   return s;
 }
