@@ -55,6 +55,10 @@
 #include "struct_hppa.h"
 #define HAVE_ABI_SIZES TRUE
 #else
+#ifdef HAVE_CPU_SPARC
+#include "struct_sparc.h"
+#define HAVE_ABI_SIZES TRUE
+#else
 /* in case someone wants to generate a new arch */
 #include "struct_i386.h"
 #define HAVE_ABI_SIZES FALSE
@@ -63,6 +67,7 @@
 #endif
 #endif
 #endif
+#endif
 
 GST_START_TEST (test_ABI)
 {
