@@ -52,13 +52,13 @@ gst_buffer_flag_get_type (void)
   static gsize id = 0;
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_BUFFER_FLAG_READONLY), "GST_BUFFER_FLAG_READONLY",
-        "readonly"},
+          "readonly"},
     {C_FLAGS (GST_BUFFER_FLAG_PREROLL), "GST_BUFFER_FLAG_PREROLL", "preroll"},
     {C_FLAGS (GST_BUFFER_FLAG_DISCONT), "GST_BUFFER_FLAG_DISCONT", "discont"},
     {C_FLAGS (GST_BUFFER_FLAG_IN_CAPS), "GST_BUFFER_FLAG_IN_CAPS", "in-caps"},
     {C_FLAGS (GST_BUFFER_FLAG_GAP), "GST_BUFFER_FLAG_GAP", "gap"},
     {C_FLAGS (GST_BUFFER_FLAG_DELTA_UNIT), "GST_BUFFER_FLAG_DELTA_UNIT",
-        "delta-unit"},
+          "delta-unit"},
     {C_FLAGS (GST_BUFFER_FLAG_MEDIA1), "GST_BUFFER_FLAG_MEDIA1", "media1"},
     {C_FLAGS (GST_BUFFER_FLAG_MEDIA2), "GST_BUFFER_FLAG_MEDIA2", "media2"},
     {C_FLAGS (GST_BUFFER_FLAG_MEDIA3), "GST_BUFFER_FLAG_MEDIA3", "media3"},
@@ -81,7 +81,7 @@ gst_buffer_copy_flags_get_type (void)
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_BUFFER_COPY_FLAGS), "GST_BUFFER_COPY_FLAGS", "flags"},
     {C_FLAGS (GST_BUFFER_COPY_TIMESTAMPS), "GST_BUFFER_COPY_TIMESTAMPS",
-        "timestamps"},
+          "timestamps"},
     {C_FLAGS (GST_BUFFER_COPY_CAPS), "GST_BUFFER_COPY_CAPS", "caps"},
     {0, NULL, NULL}
   };
@@ -94,6 +94,27 @@ gst_buffer_copy_flags_get_type (void)
   return (GType) id;
 }
 
+/* enumerations from "gstbufferlist.h" */
+GType
+gst_buffer_list_item_get_type (void)
+{
+  static gsize id = 0;
+  static const GEnumValue values[] = {
+    {C_ENUM (GST_BUFFER_LIST_CONTINUE), "GST_BUFFER_LIST_CONTINUE", "continue"},
+    {C_ENUM (GST_BUFFER_LIST_SKIP_GROUP), "GST_BUFFER_LIST_SKIP_GROUP",
+          "skip-group"},
+    {C_ENUM (GST_BUFFER_LIST_END), "GST_BUFFER_LIST_END", "end"},
+    {0, NULL, NULL}
+  };
+
+  if (g_once_init_enter (&id)) {
+    GType tmp = g_enum_register_static ("GstBufferListItem", values);
+    g_once_init_leave (&id, tmp);
+  }
+
+  return (GType) id;
+}
+
 /* enumerations from "gstbus.h" */
 GType
 gst_bus_flags_get_type (void)
@@ -198,17 +219,17 @@ gst_clock_flags_get_type (void)
   static gsize id = 0;
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_CLOCK_FLAG_CAN_DO_SINGLE_SYNC),
-        "GST_CLOCK_FLAG_CAN_DO_SINGLE_SYNC", "can-do-single-sync"},
+          "GST_CLOCK_FLAG_CAN_DO_SINGLE_SYNC", "can-do-single-sync"},
     {C_FLAGS (GST_CLOCK_FLAG_CAN_DO_SINGLE_ASYNC),
-        "GST_CLOCK_FLAG_CAN_DO_SINGLE_ASYNC", "can-do-single-async"},
+          "GST_CLOCK_FLAG_CAN_DO_SINGLE_ASYNC", "can-do-single-async"},
     {C_FLAGS (GST_CLOCK_FLAG_CAN_DO_PERIODIC_SYNC),
-        "GST_CLOCK_FLAG_CAN_DO_PERIODIC_SYNC", "can-do-periodic-sync"},
+          "GST_CLOCK_FLAG_CAN_DO_PERIODIC_SYNC", "can-do-periodic-sync"},
     {C_FLAGS (GST_CLOCK_FLAG_CAN_DO_PERIODIC_ASYNC),
-        "GST_CLOCK_FLAG_CAN_DO_PERIODIC_ASYNC", "can-do-periodic-async"},
+          "GST_CLOCK_FLAG_CAN_DO_PERIODIC_ASYNC", "can-do-periodic-async"},
     {C_FLAGS (GST_CLOCK_FLAG_CAN_SET_RESOLUTION),
-        "GST_CLOCK_FLAG_CAN_SET_RESOLUTION", "can-set-resolution"},
+          "GST_CLOCK_FLAG_CAN_SET_RESOLUTION", "can-set-resolution"},
     {C_FLAGS (GST_CLOCK_FLAG_CAN_SET_MASTER), "GST_CLOCK_FLAG_CAN_SET_MASTER",
-        "can-set-master"},
+          "can-set-master"},
     {C_FLAGS (GST_CLOCK_FLAG_LAST), "GST_CLOCK_FLAG_LAST", "last"},
     {0, NULL, NULL}
   };
@@ -228,13 +249,13 @@ gst_debug_graph_details_get_type (void)
   static gsize id = 0;
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_DEBUG_GRAPH_SHOW_MEDIA_TYPE),
-        "GST_DEBUG_GRAPH_SHOW_MEDIA_TYPE", "media-type"},
+          "GST_DEBUG_GRAPH_SHOW_MEDIA_TYPE", "media-type"},
     {C_FLAGS (GST_DEBUG_GRAPH_SHOW_CAPS_DETAILS),
-        "GST_DEBUG_GRAPH_SHOW_CAPS_DETAILS", "caps-details"},
+          "GST_DEBUG_GRAPH_SHOW_CAPS_DETAILS", "caps-details"},
     {C_FLAGS (GST_DEBUG_GRAPH_SHOW_NON_DEFAULT_PARAMS),
-        "GST_DEBUG_GRAPH_SHOW_NON_DEFAULT_PARAMS", "non-default-params"},
+          "GST_DEBUG_GRAPH_SHOW_NON_DEFAULT_PARAMS", "non-default-params"},
     {C_FLAGS (GST_DEBUG_GRAPH_SHOW_STATES), "GST_DEBUG_GRAPH_SHOW_STATES",
-        "states"},
+          "states"},
     {C_FLAGS (GST_DEBUG_GRAPH_SHOW_ALL), "GST_DEBUG_GRAPH_SHOW_ALL", "all"},
     {0, NULL, NULL}
   };
@@ -278,7 +299,7 @@ gst_state_change_return_get_type (void)
     {C_ENUM (GST_STATE_CHANGE_SUCCESS), "GST_STATE_CHANGE_SUCCESS", "success"},
     {C_ENUM (GST_STATE_CHANGE_ASYNC), "GST_STATE_CHANGE_ASYNC", "async"},
     {C_ENUM (GST_STATE_CHANGE_NO_PREROLL), "GST_STATE_CHANGE_NO_PREROLL",
-        "no-preroll"},
+          "no-preroll"},
     {0, NULL, NULL}
   };
 
@@ -296,17 +317,17 @@ gst_state_change_get_type (void)
   static gsize id = 0;
   static const GEnumValue values[] = {
     {C_ENUM (GST_STATE_CHANGE_NULL_TO_READY), "GST_STATE_CHANGE_NULL_TO_READY",
-        "null-to-ready"},
+          "null-to-ready"},
     {C_ENUM (GST_STATE_CHANGE_READY_TO_PAUSED),
-        "GST_STATE_CHANGE_READY_TO_PAUSED", "ready-to-paused"},
+          "GST_STATE_CHANGE_READY_TO_PAUSED", "ready-to-paused"},
     {C_ENUM (GST_STATE_CHANGE_PAUSED_TO_PLAYING),
-        "GST_STATE_CHANGE_PAUSED_TO_PLAYING", "paused-to-playing"},
+          "GST_STATE_CHANGE_PAUSED_TO_PLAYING", "paused-to-playing"},
     {C_ENUM (GST_STATE_CHANGE_PLAYING_TO_PAUSED),
-        "GST_STATE_CHANGE_PLAYING_TO_PAUSED", "playing-to-paused"},
+          "GST_STATE_CHANGE_PLAYING_TO_PAUSED", "playing-to-paused"},
     {C_ENUM (GST_STATE_CHANGE_PAUSED_TO_READY),
-        "GST_STATE_CHANGE_PAUSED_TO_READY", "paused-to-ready"},
+          "GST_STATE_CHANGE_PAUSED_TO_READY", "paused-to-ready"},
     {C_ENUM (GST_STATE_CHANGE_READY_TO_NULL), "GST_STATE_CHANGE_READY_TO_NULL",
-        "ready-to-null"},
+          "ready-to-null"},
     {0, NULL, NULL}
   };
 
@@ -324,10 +345,10 @@ gst_element_flags_get_type (void)
   static gsize id = 0;
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_ELEMENT_LOCKED_STATE), "GST_ELEMENT_LOCKED_STATE",
-        "locked-state"},
+          "locked-state"},
     {C_FLAGS (GST_ELEMENT_IS_SINK), "GST_ELEMENT_IS_SINK", "is-sink"},
     {C_FLAGS (GST_ELEMENT_UNPARENTING), "GST_ELEMENT_UNPARENTING",
-        "unparenting"},
+          "unparenting"},
     {C_FLAGS (GST_ELEMENT_FLAG_LAST), "GST_ELEMENT_FLAG_LAST", "flag-last"},
     {0, NULL, NULL}
   };
@@ -349,23 +370,23 @@ gst_core_error_get_type (void)
     {C_ENUM (GST_CORE_ERROR_FAILED), "GST_CORE_ERROR_FAILED", "failed"},
     {C_ENUM (GST_CORE_ERROR_TOO_LAZY), "GST_CORE_ERROR_TOO_LAZY", "too-lazy"},
     {C_ENUM (GST_CORE_ERROR_NOT_IMPLEMENTED), "GST_CORE_ERROR_NOT_IMPLEMENTED",
-        "not-implemented"},
+          "not-implemented"},
     {C_ENUM (GST_CORE_ERROR_STATE_CHANGE), "GST_CORE_ERROR_STATE_CHANGE",
-        "state-change"},
+          "state-change"},
     {C_ENUM (GST_CORE_ERROR_PAD), "GST_CORE_ERROR_PAD", "pad"},
     {C_ENUM (GST_CORE_ERROR_THREAD), "GST_CORE_ERROR_THREAD", "thread"},
     {C_ENUM (GST_CORE_ERROR_NEGOTIATION), "GST_CORE_ERROR_NEGOTIATION",
-        "negotiation"},
+          "negotiation"},
     {C_ENUM (GST_CORE_ERROR_EVENT), "GST_CORE_ERROR_EVENT", "event"},
     {C_ENUM (GST_CORE_ERROR_SEEK), "GST_CORE_ERROR_SEEK", "seek"},
     {C_ENUM (GST_CORE_ERROR_CAPS), "GST_CORE_ERROR_CAPS", "caps"},
     {C_ENUM (GST_CORE_ERROR_TAG), "GST_CORE_ERROR_TAG", "tag"},
     {C_ENUM (GST_CORE_ERROR_MISSING_PLUGIN), "GST_CORE_ERROR_MISSING_PLUGIN",
-        "missing-plugin"},
+          "missing-plugin"},
     {C_ENUM (GST_CORE_ERROR_CLOCK), "GST_CORE_ERROR_CLOCK", "clock"},
     {C_ENUM (GST_CORE_ERROR_DISABLED), "GST_CORE_ERROR_DISABLED", "disabled"},
     {C_ENUM (GST_CORE_ERROR_NUM_ERRORS), "GST_CORE_ERROR_NUM_ERRORS",
-        "num-errors"},
+          "num-errors"},
     {0, NULL, NULL}
   };
 
@@ -384,15 +405,15 @@ gst_library_error_get_type (void)
   static const GEnumValue values[] = {
     {C_ENUM (GST_LIBRARY_ERROR_FAILED), "GST_LIBRARY_ERROR_FAILED", "failed"},
     {C_ENUM (GST_LIBRARY_ERROR_TOO_LAZY), "GST_LIBRARY_ERROR_TOO_LAZY",
-        "too-lazy"},
+          "too-lazy"},
     {C_ENUM (GST_LIBRARY_ERROR_INIT), "GST_LIBRARY_ERROR_INIT", "init"},
     {C_ENUM (GST_LIBRARY_ERROR_SHUTDOWN), "GST_LIBRARY_ERROR_SHUTDOWN",
-        "shutdown"},
+          "shutdown"},
     {C_ENUM (GST_LIBRARY_ERROR_SETTINGS), "GST_LIBRARY_ERROR_SETTINGS",
-        "settings"},
+          "settings"},
     {C_ENUM (GST_LIBRARY_ERROR_ENCODE), "GST_LIBRARY_ERROR_ENCODE", "encode"},
     {C_ENUM (GST_LIBRARY_ERROR_NUM_ERRORS), "GST_LIBRARY_ERROR_NUM_ERRORS",
-        "num-errors"},
+          "num-errors"},
     {0, NULL, NULL}
   };
 
@@ -411,27 +432,27 @@ gst_resource_error_get_type (void)
   static const GEnumValue values[] = {
     {C_ENUM (GST_RESOURCE_ERROR_FAILED), "GST_RESOURCE_ERROR_FAILED", "failed"},
     {C_ENUM (GST_RESOURCE_ERROR_TOO_LAZY), "GST_RESOURCE_ERROR_TOO_LAZY",
-        "too-lazy"},
+          "too-lazy"},
     {C_ENUM (GST_RESOURCE_ERROR_NOT_FOUND), "GST_RESOURCE_ERROR_NOT_FOUND",
-        "not-found"},
+          "not-found"},
     {C_ENUM (GST_RESOURCE_ERROR_BUSY), "GST_RESOURCE_ERROR_BUSY", "busy"},
     {C_ENUM (GST_RESOURCE_ERROR_OPEN_READ), "GST_RESOURCE_ERROR_OPEN_READ",
-        "open-read"},
+          "open-read"},
     {C_ENUM (GST_RESOURCE_ERROR_OPEN_WRITE), "GST_RESOURCE_ERROR_OPEN_WRITE",
-        "open-write"},
+          "open-write"},
     {C_ENUM (GST_RESOURCE_ERROR_OPEN_READ_WRITE),
-        "GST_RESOURCE_ERROR_OPEN_READ_WRITE", "open-read-write"},
+          "GST_RESOURCE_ERROR_OPEN_READ_WRITE", "open-read-write"},
     {C_ENUM (GST_RESOURCE_ERROR_CLOSE), "GST_RESOURCE_ERROR_CLOSE", "close"},
     {C_ENUM (GST_RESOURCE_ERROR_READ), "GST_RESOURCE_ERROR_READ", "read"},
     {C_ENUM (GST_RESOURCE_ERROR_WRITE), "GST_RESOURCE_ERROR_WRITE", "write"},
     {C_ENUM (GST_RESOURCE_ERROR_SEEK), "GST_RESOURCE_ERROR_SEEK", "seek"},
     {C_ENUM (GST_RESOURCE_ERROR_SYNC), "GST_RESOURCE_ERROR_SYNC", "sync"},
     {C_ENUM (GST_RESOURCE_ERROR_SETTINGS), "GST_RESOURCE_ERROR_SETTINGS",
-        "settings"},
+          "settings"},
     {C_ENUM (GST_RESOURCE_ERROR_NO_SPACE_LEFT),
-        "GST_RESOURCE_ERROR_NO_SPACE_LEFT", "no-space-left"},
+          "GST_RESOURCE_ERROR_NO_SPACE_LEFT", "no-space-left"},
     {C_ENUM (GST_RESOURCE_ERROR_NUM_ERRORS), "GST_RESOURCE_ERROR_NUM_ERRORS",
-        "num-errors"},
+          "num-errors"},
     {0, NULL, NULL}
   };
 
@@ -450,15 +471,15 @@ gst_stream_error_get_type (void)
   static const GEnumValue values[] = {
     {C_ENUM (GST_STREAM_ERROR_FAILED), "GST_STREAM_ERROR_FAILED", "failed"},
     {C_ENUM (GST_STREAM_ERROR_TOO_LAZY), "GST_STREAM_ERROR_TOO_LAZY",
-        "too-lazy"},
+          "too-lazy"},
     {C_ENUM (GST_STREAM_ERROR_NOT_IMPLEMENTED),
-        "GST_STREAM_ERROR_NOT_IMPLEMENTED", "not-implemented"},
+          "GST_STREAM_ERROR_NOT_IMPLEMENTED", "not-implemented"},
     {C_ENUM (GST_STREAM_ERROR_TYPE_NOT_FOUND),
-        "GST_STREAM_ERROR_TYPE_NOT_FOUND", "type-not-found"},
+          "GST_STREAM_ERROR_TYPE_NOT_FOUND", "type-not-found"},
     {C_ENUM (GST_STREAM_ERROR_WRONG_TYPE), "GST_STREAM_ERROR_WRONG_TYPE",
-        "wrong-type"},
+          "wrong-type"},
     {C_ENUM (GST_STREAM_ERROR_CODEC_NOT_FOUND),
-        "GST_STREAM_ERROR_CODEC_NOT_FOUND", "codec-not-found"},
+          "GST_STREAM_ERROR_CODEC_NOT_FOUND", "codec-not-found"},
     {C_ENUM (GST_STREAM_ERROR_DECODE), "GST_STREAM_ERROR_DECODE", "decode"},
     {C_ENUM (GST_STREAM_ERROR_ENCODE), "GST_STREAM_ERROR_ENCODE", "encode"},
     {C_ENUM (GST_STREAM_ERROR_DEMUX), "GST_STREAM_ERROR_DEMUX", "demux"},
@@ -466,9 +487,9 @@ gst_stream_error_get_type (void)
     {C_ENUM (GST_STREAM_ERROR_FORMAT), "GST_STREAM_ERROR_FORMAT", "format"},
     {C_ENUM (GST_STREAM_ERROR_DECRYPT), "GST_STREAM_ERROR_DECRYPT", "decrypt"},
     {C_ENUM (GST_STREAM_ERROR_DECRYPT_NOKEY), "GST_STREAM_ERROR_DECRYPT_NOKEY",
-        "decrypt-nokey"},
+          "decrypt-nokey"},
     {C_ENUM (GST_STREAM_ERROR_NUM_ERRORS), "GST_STREAM_ERROR_NUM_ERRORS",
-        "num-errors"},
+          "num-errors"},
     {0, NULL, NULL}
   };
 
@@ -488,9 +509,9 @@ gst_event_type_flags_get_type (void)
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_EVENT_TYPE_UPSTREAM), "GST_EVENT_TYPE_UPSTREAM", "upstream"},
     {C_FLAGS (GST_EVENT_TYPE_DOWNSTREAM), "GST_EVENT_TYPE_DOWNSTREAM",
-        "downstream"},
+          "downstream"},
     {C_FLAGS (GST_EVENT_TYPE_SERIALIZED), "GST_EVENT_TYPE_SERIALIZED",
-        "serialized"},
+          "serialized"},
     {0, NULL, NULL}
   };
 
@@ -514,19 +535,21 @@ gst_event_type_get_type (void)
     {C_ENUM (GST_EVENT_NEWSEGMENT), "GST_EVENT_NEWSEGMENT", "newsegment"},
     {C_ENUM (GST_EVENT_TAG), "GST_EVENT_TAG", "tag"},
     {C_ENUM (GST_EVENT_BUFFERSIZE), "GST_EVENT_BUFFERSIZE", "buffersize"},
+    {C_ENUM (GST_EVENT_SINK_MESSAGE), "GST_EVENT_SINK_MESSAGE", "sink-message"},
     {C_ENUM (GST_EVENT_QOS), "GST_EVENT_QOS", "qos"},
     {C_ENUM (GST_EVENT_SEEK), "GST_EVENT_SEEK", "seek"},
     {C_ENUM (GST_EVENT_NAVIGATION), "GST_EVENT_NAVIGATION", "navigation"},
     {C_ENUM (GST_EVENT_LATENCY), "GST_EVENT_LATENCY", "latency"},
+    {C_ENUM (GST_EVENT_STEP), "GST_EVENT_STEP", "step"},
     {C_ENUM (GST_EVENT_CUSTOM_UPSTREAM), "GST_EVENT_CUSTOM_UPSTREAM",
-        "custom-upstream"},
+          "custom-upstream"},
     {C_ENUM (GST_EVENT_CUSTOM_DOWNSTREAM), "GST_EVENT_CUSTOM_DOWNSTREAM",
-        "custom-downstream"},
+          "custom-downstream"},
     {C_ENUM (GST_EVENT_CUSTOM_DOWNSTREAM_OOB),
-        "GST_EVENT_CUSTOM_DOWNSTREAM_OOB", "custom-downstream-oob"},
+          "GST_EVENT_CUSTOM_DOWNSTREAM_OOB", "custom-downstream-oob"},
     {C_ENUM (GST_EVENT_CUSTOM_BOTH), "GST_EVENT_CUSTOM_BOTH", "custom-both"},
     {C_ENUM (GST_EVENT_CUSTOM_BOTH_OOB), "GST_EVENT_CUSTOM_BOTH_OOB",
-        "custom-both-oob"},
+          "custom-both-oob"},
     {0, NULL, NULL}
   };
 
@@ -630,7 +653,7 @@ gst_index_entry_type_get_type (void)
   static const GEnumValue values[] = {
     {C_ENUM (GST_INDEX_ENTRY_ID), "GST_INDEX_ENTRY_ID", "id"},
     {C_ENUM (GST_INDEX_ENTRY_ASSOCIATION), "GST_INDEX_ENTRY_ASSOCIATION",
-        "association"},
+          "association"},
     {C_ENUM (GST_INDEX_ENTRY_OBJECT), "GST_INDEX_ENTRY_OBJECT", "object"},
     {C_ENUM (GST_INDEX_ENTRY_FORMAT), "GST_INDEX_ENTRY_FORMAT", "format"},
     {0, NULL, NULL}
@@ -670,9 +693,9 @@ gst_assoc_flags_get_type (void)
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_ASSOCIATION_FLAG_NONE), "GST_ASSOCIATION_FLAG_NONE", "none"},
     {C_FLAGS (GST_ASSOCIATION_FLAG_KEY_UNIT), "GST_ASSOCIATION_FLAG_KEY_UNIT",
-        "key-unit"},
+          "key-unit"},
     {C_FLAGS (GST_ASSOCIATION_FLAG_DELTA_UNIT),
-        "GST_ASSOCIATION_FLAG_DELTA_UNIT", "delta-unit"},
+          "GST_ASSOCIATION_FLAG_DELTA_UNIT", "delta-unit"},
     {C_FLAGS (GST_ASSOCIATION_FLAG_LAST), "GST_ASSOCIATION_FLAG_LAST", "last"},
     {0, NULL, NULL}
   };
@@ -837,32 +860,33 @@ gst_message_type_get_type (void)
     {C_FLAGS (GST_MESSAGE_TAG), "GST_MESSAGE_TAG", "tag"},
     {C_FLAGS (GST_MESSAGE_BUFFERING), "GST_MESSAGE_BUFFERING", "buffering"},
     {C_FLAGS (GST_MESSAGE_STATE_CHANGED), "GST_MESSAGE_STATE_CHANGED",
-        "state-changed"},
+          "state-changed"},
     {C_FLAGS (GST_MESSAGE_STATE_DIRTY), "GST_MESSAGE_STATE_DIRTY",
-        "state-dirty"},
+          "state-dirty"},
     {C_FLAGS (GST_MESSAGE_STEP_DONE), "GST_MESSAGE_STEP_DONE", "step-done"},
     {C_FLAGS (GST_MESSAGE_CLOCK_PROVIDE), "GST_MESSAGE_CLOCK_PROVIDE",
-        "clock-provide"},
+          "clock-provide"},
     {C_FLAGS (GST_MESSAGE_CLOCK_LOST), "GST_MESSAGE_CLOCK_LOST", "clock-lost"},
     {C_FLAGS (GST_MESSAGE_NEW_CLOCK), "GST_MESSAGE_NEW_CLOCK", "new-clock"},
     {C_FLAGS (GST_MESSAGE_STRUCTURE_CHANGE), "GST_MESSAGE_STRUCTURE_CHANGE",
-        "structure-change"},
+          "structure-change"},
     {C_FLAGS (GST_MESSAGE_STREAM_STATUS), "GST_MESSAGE_STREAM_STATUS",
-        "stream-status"},
+          "stream-status"},
     {C_FLAGS (GST_MESSAGE_APPLICATION), "GST_MESSAGE_APPLICATION",
-        "application"},
+          "application"},
     {C_FLAGS (GST_MESSAGE_ELEMENT), "GST_MESSAGE_ELEMENT", "element"},
     {C_FLAGS (GST_MESSAGE_SEGMENT_START), "GST_MESSAGE_SEGMENT_START",
-        "segment-start"},
+          "segment-start"},
     {C_FLAGS (GST_MESSAGE_SEGMENT_DONE), "GST_MESSAGE_SEGMENT_DONE",
-        "segment-done"},
+          "segment-done"},
     {C_FLAGS (GST_MESSAGE_DURATION), "GST_MESSAGE_DURATION", "duration"},
     {C_FLAGS (GST_MESSAGE_LATENCY), "GST_MESSAGE_LATENCY", "latency"},
     {C_FLAGS (GST_MESSAGE_ASYNC_START), "GST_MESSAGE_ASYNC_START",
-        "async-start"},
+          "async-start"},
     {C_FLAGS (GST_MESSAGE_ASYNC_DONE), "GST_MESSAGE_ASYNC_DONE", "async-done"},
     {C_FLAGS (GST_MESSAGE_REQUEST_STATE), "GST_MESSAGE_REQUEST_STATE",
-        "request-state"},
+          "request-state"},
+    {C_FLAGS (GST_MESSAGE_STEP_START), "GST_MESSAGE_STEP_START", "step-start"},
     {C_FLAGS (GST_MESSAGE_ANY), "GST_MESSAGE_ANY", "any"},
     {0, NULL, NULL}
   };
@@ -881,9 +905,9 @@ gst_structure_change_type_get_type (void)
   static gsize id = 0;
   static const GEnumValue values[] = {
     {C_ENUM (GST_STRUCTURE_CHANGE_TYPE_PAD_LINK),
-        "GST_STRUCTURE_CHANGE_TYPE_PAD_LINK", "link"},
+          "GST_STRUCTURE_CHANGE_TYPE_PAD_LINK", "link"},
     {C_ENUM (GST_STRUCTURE_CHANGE_TYPE_PAD_UNLINK),
-        "GST_STRUCTURE_CHANGE_TYPE_PAD_UNLINK", "unlink"},
+          "GST_STRUCTURE_CHANGE_TYPE_PAD_UNLINK", "unlink"},
     {0, NULL, NULL}
   };
 
@@ -895,6 +919,36 @@ gst_structure_change_type_get_type (void)
   return (GType) id;
 }
 
+GType
+gst_stream_status_type_get_type (void)
+{
+  static gsize id = 0;
+  static const GEnumValue values[] = {
+    {C_ENUM (GST_STREAM_STATUS_TYPE_CREATE), "GST_STREAM_STATUS_TYPE_CREATE",
+          "create"},
+    {C_ENUM (GST_STREAM_STATUS_TYPE_ENTER), "GST_STREAM_STATUS_TYPE_ENTER",
+          "enter"},
+    {C_ENUM (GST_STREAM_STATUS_TYPE_LEAVE), "GST_STREAM_STATUS_TYPE_LEAVE",
+          "leave"},
+    {C_ENUM (GST_STREAM_STATUS_TYPE_DESTROY), "GST_STREAM_STATUS_TYPE_DESTROY",
+          "destroy"},
+    {C_ENUM (GST_STREAM_STATUS_TYPE_START), "GST_STREAM_STATUS_TYPE_START",
+          "start"},
+    {C_ENUM (GST_STREAM_STATUS_TYPE_PAUSE), "GST_STREAM_STATUS_TYPE_PAUSE",
+          "pause"},
+    {C_ENUM (GST_STREAM_STATUS_TYPE_STOP), "GST_STREAM_STATUS_TYPE_STOP",
+          "stop"},
+    {0, NULL, NULL}
+  };
+
+  if (g_once_init_enter (&id)) {
+    GType tmp = g_enum_register_static ("GstStreamStatusType", values);
+    g_once_init_leave (&id, tmp);
+  }
+
+  return (GType) id;
+}
+
 /* enumerations from "gstminiobject.h" */
 GType
 gst_mini_object_flags_get_type (void)
@@ -902,7 +956,7 @@ gst_mini_object_flags_get_type (void)
   static gsize id = 0;
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_MINI_OBJECT_FLAG_READONLY), "GST_MINI_OBJECT_FLAG_READONLY",
-        "readonly"},
+          "readonly"},
     {C_FLAGS (GST_MINI_OBJECT_FLAG_LAST), "GST_MINI_OBJECT_FLAG_LAST", "last"},
     {0, NULL, NULL}
   };
@@ -923,10 +977,10 @@ gst_pad_link_return_get_type (void)
   static const GEnumValue values[] = {
     {C_ENUM (GST_PAD_LINK_OK), "GST_PAD_LINK_OK", "ok"},
     {C_ENUM (GST_PAD_LINK_WRONG_HIERARCHY), "GST_PAD_LINK_WRONG_HIERARCHY",
-        "wrong-hierarchy"},
+          "wrong-hierarchy"},
     {C_ENUM (GST_PAD_LINK_WAS_LINKED), "GST_PAD_LINK_WAS_LINKED", "was-linked"},
     {C_ENUM (GST_PAD_LINK_WRONG_DIRECTION), "GST_PAD_LINK_WRONG_DIRECTION",
-        "wrong-direction"},
+          "wrong-direction"},
     {C_ENUM (GST_PAD_LINK_NOFORMAT), "GST_PAD_LINK_NOFORMAT", "noformat"},
     {C_ENUM (GST_PAD_LINK_NOSCHED), "GST_PAD_LINK_NOSCHED", "nosched"},
     {C_ENUM (GST_PAD_LINK_REFUSED), "GST_PAD_LINK_REFUSED", "refused"},
@@ -947,17 +1001,17 @@ gst_flow_return_get_type (void)
   static gsize id = 0;
   static const GEnumValue values[] = {
     {C_ENUM (GST_FLOW_CUSTOM_SUCCESS), "GST_FLOW_CUSTOM_SUCCESS",
-        "custom-success"},
+          "custom-success"},
     {C_ENUM (GST_FLOW_RESEND), "GST_FLOW_RESEND", "resend"},
     {C_ENUM (GST_FLOW_OK), "GST_FLOW_OK", "ok"},
     {C_ENUM (GST_FLOW_NOT_LINKED), "GST_FLOW_NOT_LINKED", "not-linked"},
     {C_ENUM (GST_FLOW_WRONG_STATE), "GST_FLOW_WRONG_STATE", "wrong-state"},
     {C_ENUM (GST_FLOW_UNEXPECTED), "GST_FLOW_UNEXPECTED", "unexpected"},
     {C_ENUM (GST_FLOW_NOT_NEGOTIATED), "GST_FLOW_NOT_NEGOTIATED",
-        "not-negotiated"},
+          "not-negotiated"},
     {C_ENUM (GST_FLOW_ERROR), "GST_FLOW_ERROR", "error"},
     {C_ENUM (GST_FLOW_NOT_SUPPORTED), "GST_FLOW_NOT_SUPPORTED",
-        "not-supported"},
+          "not-supported"},
     {C_ENUM (GST_FLOW_CUSTOM_ERROR), "GST_FLOW_CUSTOM_ERROR", "custom-error"},
     {0, NULL, NULL}
   };
@@ -1057,7 +1111,7 @@ gst_pad_template_flags_get_type (void)
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_PAD_TEMPLATE_FIXED), "GST_PAD_TEMPLATE_FIXED", "fixed"},
     {C_FLAGS (GST_PAD_TEMPLATE_FLAG_LAST), "GST_PAD_TEMPLATE_FLAG_LAST",
-        "flag-last"},
+          "flag-last"},
     {0, NULL, NULL}
   };
 
@@ -1076,7 +1130,7 @@ gst_pipeline_flags_get_type (void)
   static gsize id = 0;
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_PIPELINE_FLAG_FIXED_CLOCK), "GST_PIPELINE_FLAG_FIXED_CLOCK",
-        "fixed-clock"},
+          "fixed-clock"},
     {C_FLAGS (GST_PIPELINE_FLAG_LAST), "GST_PIPELINE_FLAG_LAST", "last"},
     {0, NULL, NULL}
   };
@@ -1097,9 +1151,9 @@ gst_plugin_error_get_type (void)
   static const GEnumValue values[] = {
     {C_ENUM (GST_PLUGIN_ERROR_MODULE), "GST_PLUGIN_ERROR_MODULE", "module"},
     {C_ENUM (GST_PLUGIN_ERROR_DEPENDENCIES), "GST_PLUGIN_ERROR_DEPENDENCIES",
-        "dependencies"},
+          "dependencies"},
     {C_ENUM (GST_PLUGIN_ERROR_NAME_MISMATCH), "GST_PLUGIN_ERROR_NAME_MISMATCH",
-        "name-mismatch"},
+          "name-mismatch"},
     {0, NULL, NULL}
   };
 
@@ -1117,6 +1171,8 @@ gst_plugin_flags_get_type (void)
   static gsize id = 0;
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_PLUGIN_FLAG_CACHED), "GST_PLUGIN_FLAG_CACHED", "cached"},
+    {C_FLAGS (GST_PLUGIN_FLAG_BLACKLISTED), "GST_PLUGIN_FLAG_BLACKLISTED",
+          "blacklisted"},
     {0, NULL, NULL}
   };
 
@@ -1134,15 +1190,15 @@ gst_plugin_dependency_flags_get_type (void)
   static gsize id = 0;
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_PLUGIN_DEPENDENCY_FLAG_NONE),
-        "GST_PLUGIN_DEPENDENCY_FLAG_NONE", "none"},
+          "GST_PLUGIN_DEPENDENCY_FLAG_NONE", "none"},
     {C_FLAGS (GST_PLUGIN_DEPENDENCY_FLAG_RECURSE),
-        "GST_PLUGIN_DEPENDENCY_FLAG_RECURSE", "recurse"},
+          "GST_PLUGIN_DEPENDENCY_FLAG_RECURSE", "recurse"},
     {C_FLAGS (GST_PLUGIN_DEPENDENCY_FLAG_PATHS_ARE_DEFAULT_ONLY),
           "GST_PLUGIN_DEPENDENCY_FLAG_PATHS_ARE_DEFAULT_ONLY",
-        "paths-are-default-only"},
+          "paths-are-default-only"},
     {C_FLAGS (GST_PLUGIN_DEPENDENCY_FLAG_FILE_NAME_IS_SUFFIX),
           "GST_PLUGIN_DEPENDENCY_FLAG_FILE_NAME_IS_SUFFIX",
-        "file-name-is-suffix"},
+          "file-name-is-suffix"},
     {0, NULL, NULL}
   };
 
@@ -1233,7 +1289,7 @@ gst_clock_type_get_type (void)
   static const GEnumValue values[] = {
     {C_ENUM (GST_CLOCK_TYPE_REALTIME), "GST_CLOCK_TYPE_REALTIME", "realtime"},
     {C_ENUM (GST_CLOCK_TYPE_MONOTONIC), "GST_CLOCK_TYPE_MONOTONIC",
-        "monotonic"},
+          "monotonic"},
     {0, NULL, NULL}
   };
 
@@ -1253,7 +1309,7 @@ gst_tag_merge_mode_get_type (void)
   static const GEnumValue values[] = {
     {C_ENUM (GST_TAG_MERGE_UNDEFINED), "GST_TAG_MERGE_UNDEFINED", "undefined"},
     {C_ENUM (GST_TAG_MERGE_REPLACE_ALL), "GST_TAG_MERGE_REPLACE_ALL",
-        "replace-all"},
+          "replace-all"},
     {C_ENUM (GST_TAG_MERGE_REPLACE), "GST_TAG_MERGE_REPLACE", "replace"},
     {C_ENUM (GST_TAG_MERGE_APPEND), "GST_TAG_MERGE_APPEND", "append"},
     {C_ENUM (GST_TAG_MERGE_PREPEND), "GST_TAG_MERGE_PREPEND", "prepend"},
@@ -1320,7 +1376,7 @@ gst_alloc_trace_flags_get_type (void)
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_ALLOC_TRACE_LIVE), "GST_ALLOC_TRACE_LIVE", "live"},
     {C_FLAGS (GST_ALLOC_TRACE_MEM_LIVE), "GST_ALLOC_TRACE_MEM_LIVE",
-        "mem-live"},
+          "mem-live"},
     {0, NULL, NULL}
   };
 
@@ -1342,7 +1398,7 @@ gst_type_find_probability_get_type (void)
     {C_ENUM (GST_TYPE_FIND_POSSIBLE), "GST_TYPE_FIND_POSSIBLE", "possible"},
     {C_ENUM (GST_TYPE_FIND_LIKELY), "GST_TYPE_FIND_LIKELY", "likely"},
     {C_ENUM (GST_TYPE_FIND_NEARLY_CERTAIN), "GST_TYPE_FIND_NEARLY_CERTAIN",
-        "nearly-certain"},
+          "nearly-certain"},
     {C_ENUM (GST_TYPE_FIND_MAXIMUM), "GST_TYPE_FIND_MAXIMUM", "maximum"},
     {0, NULL, NULL}
   };
@@ -1403,14 +1459,14 @@ gst_parse_error_get_type (void)
   static const GEnumValue values[] = {
     {C_ENUM (GST_PARSE_ERROR_SYNTAX), "GST_PARSE_ERROR_SYNTAX", "syntax"},
     {C_ENUM (GST_PARSE_ERROR_NO_SUCH_ELEMENT),
-        "GST_PARSE_ERROR_NO_SUCH_ELEMENT", "no-such-element"},
+          "GST_PARSE_ERROR_NO_SUCH_ELEMENT", "no-such-element"},
     {C_ENUM (GST_PARSE_ERROR_NO_SUCH_PROPERTY),
-        "GST_PARSE_ERROR_NO_SUCH_PROPERTY", "no-such-property"},
+          "GST_PARSE_ERROR_NO_SUCH_PROPERTY", "no-such-property"},
     {C_ENUM (GST_PARSE_ERROR_LINK), "GST_PARSE_ERROR_LINK", "link"},
     {C_ENUM (GST_PARSE_ERROR_COULD_NOT_SET_PROPERTY),
-        "GST_PARSE_ERROR_COULD_NOT_SET_PROPERTY", "could-not-set-property"},
+          "GST_PARSE_ERROR_COULD_NOT_SET_PROPERTY", "could-not-set-property"},
     {C_ENUM (GST_PARSE_ERROR_EMPTY_BIN), "GST_PARSE_ERROR_EMPTY_BIN",
-        "empty-bin"},
+          "empty-bin"},
     {C_ENUM (GST_PARSE_ERROR_EMPTY), "GST_PARSE_ERROR_EMPTY", "empty"},
     {0, NULL, NULL}
   };
@@ -1430,7 +1486,7 @@ gst_parse_flags_get_type (void)
   static const GFlagsValue values[] = {
     {C_FLAGS (GST_PARSE_FLAG_NONE), "GST_PARSE_FLAG_NONE", "none"},
     {C_FLAGS (GST_PARSE_FLAG_FATAL_ERRORS), "GST_PARSE_FLAG_FATAL_ERRORS",
-        "fatal-errors"},
+          "fatal-errors"},
     {0, NULL, NULL}
   };
 
